
// TourLand.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, September 2008

/* A top-level window which loads either a translatable land panel
   (TourLandPanel), a rotatable land panel (TourRotLandPanel), or a
   panel showing a perspective projection of the land (TourPerLandPanel).
*/


import java.awt.*;
import javax.swing.*;


public class TourLand extends JFrame
{
  private static final int TRANS_LAND_TYPE = 0;   // translatable land
  private static final int ROT_LAND_TYPE = 1;     // rotatable land
  private static final int PERS_LAND_TYPE = 2;    // perspective projection of land


  public TourLand(int landType)
  {
    super("Tour Land");
    Container c = getContentPane();
    c.setLayout( new BorderLayout() );
    
    // install the specified tour land panel
    if (landType == TRANS_LAND_TYPE)
      c.add( new TourLandPanel(), BorderLayout.CENTER);
    else if (landType == ROT_LAND_TYPE)
      c.add( new TourRotLandPanel(), BorderLayout.CENTER);
    else if (landType == PERS_LAND_TYPE)
      c.add( new TourPerLandPanel(), BorderLayout.CENTER);
    else {
      System.out.println("Unknown land type: " + landType); 
      System.exit(1);
    }

    setDefaultCloseOperation( JFrame.EXIT_ON_CLOSE );
    setResizable(false);
    pack();
    setVisible(true);
  } // end of TourLand()


// ---------------------------------

  public static void main(String args[])
  { 
    int landType;
    if (args.length == 1)
      landType = getLandType(args[0]);
    else {
      System.out.println("No land type supplied; using " + PERS_LAND_TYPE); 
      landType = PERS_LAND_TYPE;
    }

    new TourLand(landType);  
  }  // end of main()


  private static int getLandType(String arg)
  // extract the land type value from the command line arg.
  {
    int val;
    try {
      val = Integer.parseInt(arg);
    }
    catch (NumberFormatException ex){ 
      System.out.println("Incorrect format for land type; using " + PERS_LAND_TYPE); 
      val = PERS_LAND_TYPE;
    }

    if ((val != TRANS_LAND_TYPE) && (val != ROT_LAND_TYPE) &&
        (val != PERS_LAND_TYPE)) {
      System.out.println("Unknown land type; using " + PERS_LAND_TYPE); 
      val = PERS_LAND_TYPE;
    }

    return val;
  }  // end of getLandType();

} // end of TourLand class

